@@ -9,16 +9,16 @@ pub use wasmy_macros::vm_handle;
 
 pub type VmHandler = fn(&Any) -> Result<Any>;
 
-pub struct VmHandlerAPI {
+pub struct VmHandlerApi {
     method: Method,
     handler: VmHandler,
 }
 
 static COLLECT_AND_REGISTER_ONCE: Once = Once::new();
 
-impl VmHandlerAPI {
+impl VmHandlerApi {
     pub const fn new(method: Method, handler: VmHandler) -> Self {
-        VmHandlerAPI { method, handler }
+        VmHandlerApi { method, handler }
     }
     pub fn register(&self) {
         set_handler(self.method, self.handler)
@@ -41,8 +41,8 @@ lazy_static! {
 }
 
 fn collect_and_register_handlers() {
-    inventory::collect!(VmHandlerAPI);
-    for info in inventory::iter::<VmHandlerAPI> {
+    inventory::collect!(VmHandlerApi);
+    for info in inventory::iter::<VmHandlerApi> {
         info.register();
     }
     for (method, hdl) in MUX.read().unwrap().iter() {
@@ -55,10 +55,10 @@ pub fn set_handler(method: Method, hdl: VmHandler) {
 }
 
 #[allow(dead_code)]
-pub(crate) fn host_call(args_pb: &Vec<u8>) -> OutResult {
+pub(crate) fn vm_invoke(args_pb: &Vec<u8>) -> OutRets {
     match InArgs::parse_from_bytes(&args_pb) {
-        Ok(host_args) => {
-            handle(host_args)
+        Ok(vm_args) => {
+            handle(vm_args)
         }
         Err(err) => {
             ERR_CODE_PROTO.to_code_msg(err).into()
@@ -67,7 +67,7 @@ pub(crate) fn host_call(args_pb: &Vec<u8>) -> OutResult {
 }
 
 
-fn handle(args: InArgs) -> OutResult {
+fn handle(args: InArgs) -> OutRets {
     let res: Result<Any> = MUX.read().unwrap().get(&args.get_method())?(args.get_data());
     match res {
         Ok(a) => a.into(),
